@@ -1,5 +1,5 @@
 # Copyright (c) Gorilla-Lab. All rights reserved.
 from .config import (add_args, Config, ConfigDict, DictAction,
-                     merge_args_and_cfg)
+                     merge_cfg_and_args)
 
 __all__ = [k for k in globals().keys() if not k.startswith("_")]
