@@ -3,14 +3,14 @@ import numpy as np
 import torch.nn as nn
 
 
-def constant_init(module, val, bias=0):
+def constant_init(module: nn.Module, val, bias=0):
     if hasattr(module, "weight") and module.weight is not None:
         nn.init.constant_(module.weight, val)
     if hasattr(module, "bias") and module.bias is not None:
         nn.init.constant_(module.bias, bias)
 
 
-def xavier_init(module, gain=1, bias=0, distribution="normal"):
+def xavier_init(module: nn.Module, gain=1, bias=0, distribution="normal"):
     assert distribution in ["uniform", "normal"]
     if distribution == "uniform":
         nn.init.xavier_uniform_(module.weight, gain=gain)
@@ -20,19 +20,19 @@ def xavier_init(module, gain=1, bias=0, distribution="normal"):
         nn.init.constant_(module.bias, bias)
 
 
-def normal_init(module, mean=0, std=1, bias=0):
+def normal_init(module: nn.Module, mean=0, std=1, bias=0):
     nn.init.normal_(module.weight, mean, std)
     if hasattr(module, "bias") and module.bias is not None:
         nn.init.constant_(module.bias, bias)
 
 
-def uniform_init(module, a=0, b=1, bias=0):
+def uniform_init(module: nn.Module, a=0, b=1, bias=0):
     nn.init.uniform_(module.weight, a, b)
     if hasattr(module, "bias") and module.bias is not None:
         nn.init.constant_(module.bias, bias)
 
 
-def kaiming_init(module,
+def kaiming_init(module: nn.Module,
                  a=0,
                  mode="fan_out",
                  nonlinearity="relu",
